<?php
/*
 * @Author: your name
 * @Date: 2020-11-20 11:33:56
 * @LastEditTime: 2021-09-30 16:36:42
 * @LastEditors: Please set LastEditors
 * @Description: In User Settings Edit
 * @FilePath: utils\easysms\AliyunSms.php
 */


namespace app\lib\utils\easysms;


use app\lib\model\DayuSmsModel;
use Overtrue\EasySms\EasySms;
use app\lib\utils\easysms\ZthySms;
use think\Config;
use think\Exception;
use think\Log;

class AliyunSms
{
    /**
     * 通用短信验证
     * @param $mobile
     * @param string $smstemplate
     * @return bool
     * @throws \Overtrue\EasySms\Exceptions\InvalidArgumentException
     * @throws \Overtrue\EasySms\Exceptions\NoGatewayAvailableException
     * @date
     */
    public static function sendCodeSms($mobile, $smstemplate = '', $smstype = 'sms_user_newpwd')
    {
        $code = rand(10000, 99999);
        $info = "您的验证码：" . $code . "，您正进行身份验证，打死不告诉别人！";
        try {
            $result = ZthySms::sendSms($mobile, $info);
        } catch (Exception $e) {
            Log::write("错误", json_encode($e));
        }
        $res = json_decode($result, true);
        if ($res['code'] == 200) {
            try {
                DayuSmsModel::insertData($smstype, $code, $mobile, $result, "点点达", $info);
            } catch (Exception $error) {
                Log::record('短信记录异常：' . $error->getMessage(), 'error');
            }
            return true;
        }
        return false;
    }
    /**
     * @description: 提现失败短信通知
     * @param {*}
     * @return {*}
     */
    public static function withdrawErrorSms($realname, $mobile, $money, $reason)
    {
        $smstype = 'sms_withdraw';
        $info = '尊敬的' . $realname . '用户，您在平台申请提现金额' . sprintf("%.2f", $money) . '元失败。失败原因：' . $reason . '。全国服务热线：400-8073023';
        try {
            $result = ZthySms::sendSms($mobile, $info);
        } catch (Exception $e) {
            Log::write("错误", json_encode($e));
        }
        $res = json_decode($result, true);
        if ($res['code'] == 200) {
            try {
                DayuSmsModel::insertData($smstype, '', $mobile, $result, '鹿马用户提现', $info);
            } catch (Exception $error) {
                Log::record('短信记录异常：', $error->getMessage());
            }
            return true;
        }
        return false;
    }
    /**
     * @description: 用于提示用户提现成功
     * @param {*}
     * @return {*}
     */
    public static function withdrawAuditSms($realname, $mobile, $money)
    {
        $smstype = 'sms_withdraw';
        $info = '尊敬的' . $realname . '用户，您在平台申请提现金额' . sprintf("%.2f", $money) . '元已到账。全国服务热线：400-8073023';
        try {
            $result = ZthySms::sendSms($mobile, $info);
        } catch (Exception $e) {
            Log::write("错误", json_encode($e));
        }
        $res = json_decode($result, true);
        if ($res['code'] == 200) {
            try {
                DayuSmsModel::insertData($smstype, '', $mobile, $result, '鹿马用户提现', $info);
            } catch (Exception $error) {
                Log::record('短信记录异常：', $error->getMessage());
            }
            return true;
        }
        return false;
    }
    /**
     * @description: 用于提示用户提现正在审核
     * @param {*}
     * @return {*}
     */
    public static function withdrawWaitSms($realname, $mobile, $money)
    {
        $smstype = 'sms_withdraw';
        $info = '尊敬的' . $realname . '用户，您在平台申请提现金额' . sprintf("%.2f", $money) . '元正在审核中，将会在T+1时间范围内到账。全国服务热线：400-8073023';
        try {
            $result = ZthySms::sendSms($mobile, $info);
        } catch (Exception $e) {
            Log::write("错误", json_encode($e));
        }
        $res = json_decode($result, true);
        if ($res['code'] == 200) {
            try {
                DayuSmsModel::insertData($smstype, '', $mobile, $result, '鹿马用户提现', $info);
            } catch (Exception $error) {
                Log::record('短信记录异常：', $error->getMessage());
            }
            return true;
        }
        return false;
    }

    /**
     * @description: 用于提现管理员有新的洗车工入驻申请需要审核
     * @param {*}
     * @return {*}
     */
    public static function applyInformationNoticeSms($mobile, $shop_name, $smstemplate = '', $smstype = 'sms_apply', $addr = '')
    {
        $info = '来自地区：' . $addr . '有新的洗车技师申请身份认证了，请及时进行审核';
        try {
            $result = ZthySms::sendSms($mobile, $info);
        } catch (Exception $e) {
            Log::write("错误", json_encode($e));
        }
        $res = json_decode($result, true);
        if ($res['code'] == 200) {
            try {
                DayuSmsModel::insertData($smstype, '', $mobile, $result, '洗车工入驻', $info);
            } catch (Exception $error) {
                Log::record('短信记录异常：', $error->getMessage());
            }
            return true;
        }
        return false;
    }

    public static function sendDisapprveSms($mobile, $jobname = '洗车工', $reason)
    {
        $smstype = 'sms_withdraw';
        $info = '尊敬的用户,您的' . $jobname . '入驻申请被驳回，原因如下：' . $reason . '请重新提交申请';
        try {
            $result = ZthySms::sendSms($mobile, $info);
        } catch (Exception $e) {
            Log::write("错误", json_encode($e));
        }
        $res = json_decode($result, true);
        if ($res['code'] == 200) {
            try {
                DayuSmsModel::insertData($smstype, '', $mobile, $result, '洗车工入驻', $info);
            } catch (Exception $error) {
                Log::record('短信记录异常：', $error->getMessage());
            }
            return true;
        }
        return false;
    }
    /**
     * 发送短信通知代理商，有超时未接的订单
     */
    public static function sendAgentOrderNoticeSms($mobile, $tel, $order_id)
    {
        $smstype = 'ordernotice';
        $info = '点点达来新的订单了，客户电话:' . $tel . '，请尽快处理';
        try {
            $result = ZthySms::sendSms($mobile, $info);
        } catch (Exception $e) {
            Log::write("错误", json_encode($e));
        }
        $res = json_decode($result, true);
        if ($res['code'] == 200) {
            try {
                DayuSmsModel::insertData($smstype, '', $mobile, $result, '洗车订单', $info, $order_id);
            } catch (Exception $error) {
                Log::record('短信记录异常：', $error->getMessage());
            }
            return true;
        }
        return false;
    }
    /**
     * 发送短信通知客服，有超时未接的订单
     */
    public static function sendOrderNoticeSms($mobile, $addr, $order_id, $agentMobile, $siteMobile)
    {
        $smstype = 'ordernotice';
        $info = $addr . '有未接订单,订单ID：' . $order_id;
        if ($agentMobile) {
            $info = $info . ',代理商电话：' . $agentMobile;
        }
        if ($siteMobile) {
            $info = $info . ',站点电话：' . $siteMobile;
        }
        try {
            $result = ZthySms::sendSms($mobile, $info);
        } catch (Exception $e) {
            Log::write("错误", json_encode($e));
        }
        $res = json_decode($result, true);
        if ($res['code'] == 200) {
            try {
                DayuSmsModel::insertData($smstype, '', $mobile, $result, '洗车订单', $info, $order_id);
            } catch (Exception $error) {
                Log::record('短信记录异常：', $error->getMessage());
            }
            return true;
        }
        return false;
    }
    /**
     * 发送短信，提醒管理员有未审核的洗车工身份认证申请
     */
    public static function sendWasherApplyNotice($addr, $mobile = '18770001107')
    {
        $smstype = 'ordernotice';
        $info = '来自地区：' . $addr . '有新的洗车技师申请身份认证了，请及时进行审核';
        try {
            $result = ZthySms::sendSms($mobile, $info);
        } catch (Exception $e) {
            Log::write("错误", json_encode($e));
        }
        $res = json_decode($result, true);
        if ($res['code'] == 200) {
            try {
                DayuSmsModel::insertData($smstype, '', $mobile, $result, '洗车工审核', $info, 0);
            } catch (Exception $error) {
                Log::record('短信记录异常：', $error->getMessage());
            }
            return true;
        }
        return false;
    }



    /**
     * @description: 洗车工洗车完成通知车主/上门服务完成通知用户
     * @param {*}
     * @return {*}
     */
    public static function sendcarowner($mobile, $info)
    {
        $smstype = 'washercarcomplete';
        try {
            $result = ZthySms::sendSms($mobile, $info);
        } catch (Exception $e) {
            Log::write("错误", json_encode($e));
        }
        $res = json_decode($result, true);
        if ($res['code'] == 200) {
            try {
                DayuSmsModel::insertData($smstype, '', $mobile, $result, '洗车完成通知车主', $info);
            } catch (Exception $error) {
                Log::record('短信记录异常：', $error->getMessage());
            }
            return true;
        }
        return false;
    }

    /**
     * @description: 通知洗车工有新的订单已经派给他了
     * @param {*}
     * @return {*}
     */
    public static function noticeWasherAutoArrangeOrder($mobile, $order_id)
    {
        $smstype = 'autoarrangeorder';
        $info = "尊敬的洗车技师，有新的洗车订单派给你了，请尽快联系车主，如不接受后续派单，请将状态设为忙碌，如需派给其他人，请联系客服进行处理。";
        try {
            $result = ZthySms::sendSms($mobile, $info);
        } catch (Exception $e) {
            Log::write("错误", json_encode($e));
        }
        $res = json_decode($result, true);
        if ($res['code'] == 200) {
            try {
                DayuSmsModel::insertData($smstype, '', $mobile, $result, '自动派单通知洗车工', $info, $order_id);
            } catch (Exception $error) {
                Log::record('短信记录异常：', $error->getMessage());
            }
            return true;
        }
        return false;
    }

    // edit by taowujie，暂停使用阿里云短信，改为使用助通短信，后续如再次启用，取消注释即可
    // /**
    //  * 通用短信验证
    //  * @param $mobile
    //  * @param string $smstemplate
    //  * @return bool
    //  * @throws \Overtrue\EasySms\Exceptions\InvalidArgumentException
    //  * @throws \Overtrue\EasySms\Exceptions\NoGatewayAvailableException
    //  * @date
    //  */
    // public static function sendCodeSms($mobile, $smstemplate = '', $smstype = 'sms_user_newpwd')
    // {
    //     $config = Config::get("tplmsg.smsConfig"); //application/extra/tplmsg
    //     $smstemp = Config::get("tplmsg.smstemp");
    //     if (!$smstemplate) {
    //          $smstemplate = $smstemp['forgetpass'];
    //     }
    //     $easySms = new EasySms($config);
    //     $code = rand(10000, 99999);
    //     $info = "您的验证码：" . $code . "，您正进行身份验证，打死不告诉别人！";
    //     try {
    //         $result = $easySms->send(
    //             $mobile,
    //             [
    //                 'content'  => '',
    //                 'template' => $smstemplate,
    //                 'data' => [
    //                     'code' => $code
    //                 ]
    //             ],
    //             ['aliyun']
    //         );
    //     } catch (Exception $e) {
    //         Log::write("错误", json_encode($e));
    //     }
    //     $res = json_decode(json_encode($result), true);
    //     if ($res['aliyun']['status'] == "success") {
    //         try {
    //             DayuSmsModel::insertData($smstype, $code, $mobile, $result, "点点达", $info);
    //         } catch (Exception $error) {
    //             Log::record('短信记录异常：' . $error->getMessage(), 'error');
    //         }
    //         return true;
    //     }
    //     return false;
    // }
    // /**
    //  * @description: 提现失败短信通知
    //  * @param {*}
    //  * @return {*}
    //  */
    // public static function withdrawErrorSms($realname, $mobile, $money, $reason)
    // {
    //     $config = Config::get("tplmsg.smsConfig");
    //     $smstype = 'sms_withdraw';
    //     $smstemplate = 'SMS_207520959';
    //     $easySms = new EasySms($config);
    //     $info = '尊敬的' . $realname . '用户，您在平台申请提现金额' . sprintf("%.2f", $money) . '元失败。失败原因：' . $reason . '。全国服务热线：400-8073023';
    //     try {
    //         $result = $easySms->send(
    //             $mobile,
    //             [
    //                 'content'  => '',
    //                 'template' => $smstemplate,
    //                 'data' => [
    //                     'realname' => $realname,
    //                     'money' => sprintf("%.2f", $money),
    //                     'reason' => $reason
    //                 ]
    //             ],
    //             ['aliyun']
    //         );
    //     } catch (Exception $e) {
    //         Log::write("错误", json_encode($e));
    //     }
    //     $res = json_decode(json_encode($result), true);
    //     if ($res['aliyun']['status'] == "success") {
    //         try {
    //             DayuSmsModel::insertData($smstype, '', $mobile, $res['aliyun']['result'], '鹿马用户提现', $info);
    //         } catch (Exception $error) {
    //             Log::record('短信记录异常：', $error->getMessage());
    //         }
    //         return true;
    //     }
    //     return false;
    // }
    // /**
    //  * @description: 用于提示用户提现成功
    //  * @param {*}
    //  * @return {*}
    //  */
    // public static function withdrawAuditSms($realname, $mobile, $money)
    // {
    //     $config = Config::get("tplmsg.smsConfig");
    //     $smstype = 'sms_withdraw';
    //     $smstemplate = 'SMS_207962178';
    //     $easySms = new EasySms($config);
    //     $info = '尊敬的' . $realname . '用户，您在平台申请提现金额' . sprintf("%.2f", $money) . '元已到账。全国服务热线：400-8073023';
    //     try {
    //         $result = $easySms->send(
    //             $mobile,
    //             [
    //                 'content'  => '',
    //                 'template' => $smstemplate,
    //                 'data' => [
    //                     'realname' => $realname,
    //                     'money' => sprintf("%.2f", $money)
    //                 ]
    //             ],
    //             ['aliyun']
    //         );
    //     } catch (Exception $e) {
    //         Log::write("错误", json_encode($e));
    //     }
    //     $res = json_decode(json_encode($result), true);
    //     if ($res['aliyun']['status'] == "success") {
    //         try {
    //             DayuSmsModel::insertData($smstype, '', $mobile, $res['aliyun']['result'], '鹿马用户提现', $info);
    //         } catch (Exception $error) {
    //             Log::record('短信记录异常：', $error->getMessage());
    //         }
    //         return true;
    //     }
    //     return false;
    // }
    // /**
    //  * @description: 用于提示用户提现正在审核
    //  * @param {*}
    //  * @return {*}
    //  */
    // public static function withdrawWaitSms($realname, $mobile, $money)
    // {
    //     $config = Config::get("tplmsg.smsConfig");
    //     $smstype = 'sms_withdraw';
    //     $smstemplate = 'SMS_207947202';
    //     $easySms = new EasySms($config);
    //     $info = '尊敬的' . $realname . '用户，您在平台申请提现金额' . sprintf("%.2f", $money) . '元正在审核中，将会在T+1时间范围内到账。全国服务热线：400-8073023';
    //     try {
    //         $result = $easySms->send(
    //             $mobile,
    //             [
    //                 'content'  => '',
    //                 'template' => $smstemplate,
    //                 'data' => []
    //             ],
    //             ['aliyun']
    //         );
    //     } catch (Exception $e) {
    //         Log::write("错误", json_encode($e));
    //     }
    //     $res = json_decode(json_encode($result), true);
    //     if ($res['aliyun']['status'] == "success") {
    //         try {
    //             DayuSmsModel::insertData($smstype, '', $mobile, $res['aliyun']['result'], '鹿马用户提现', $info);
    //         } catch (Exception $error) {
    //             Log::record('短信记录异常：', $error->getMessage());
    //         }
    //         return true;
    //     }
    //     return false;
    // }

    // /**
    //  * @description: 用于提现管理员有新的洗车工入驻申请需要审核
    //  * @param {*}
    //  * @return {*}
    //  */
    // public static function applyInformationNoticeSms($mobile, $shop_name, $smstemplate = '', $smstype = 'sms_apply', $addr = '')
    // {
    //     $smstemp = Config::get("tplmsg.smsConfig");
    //     if (!$smstemplate) {
    //         $smstemplate = $smstemp['applywashercustomer'];
    //     }
    //     $easySms = new EasySms($smstemp);
    //     $info = '来自地区：' . $addr . '有新的洗车技师申请身份认证了，请及时进行审核';
    //     try {
    //         $result = $easySms->send(
    //             $mobile,
    //             [
    //                 'content'  => '',
    //                 'template' => $smstemplate,
    //                 'data' => [
    //                     'name' => $addr
    //                 ]
    //             ],
    //             ['aliyun']
    //         );
    //     } catch (Exception $e) {
    //         Log::write("错误", json_encode($e));
    //     }
    //     $res = json_decode(json_encode($result), true);
    //     if ($res['aliyun']['status'] == "success") {
    //         try {
    //             DayuSmsModel::insertData($smstype, '', $mobile, $res['aliyun']['result'], '洗车工入驻', $info);
    //         } catch (Exception $error) {
    //             Log::record('短信记录异常：', $error->getMessage());
    //         }
    //         return true;
    //     }
    //     return false;
    // }

    // public static function sendDisapprveSms($mobile, $jobname = '洗车工', $reason)
    // {
    //     $config = Config::get("tplmsg.smsConfig");
    //     $smstype = 'sms_withdraw';
    //     $smstemplate = 'SMS_206752743';
    //     $easySms = new EasySms($config);
    //     $audit_time = date("Y-m-d H:i:s", time());
    //     $info = '尊敬的用户,您的' . $jobname . '入驻申请被驳回，原因如下：' . $reason . '请重新提交申请';
    //     try {
    //         $result = $easySms->send(
    //             $mobile,
    //             [
    //                 'content'  => '',
    //                 'template' => $smstemplate,
    //                 'data' => [
    //                     'shop_name' => $jobname,
    //                     'reason' => $reason
    //                 ]
    //             ],
    //             ['aliyun']
    //         );
    //     } catch (Exception $e) {
    //         Log::write("错误", json_encode($e));
    //     }
    //     $res = json_decode(json_encode($result), true);
    //     if ($res['aliyun']['status'] == "success") {
    //         try {
    //             DayuSmsModel::insertData($smstype, '', $mobile, $res['aliyun']['result'], '洗车工入驻', $info);
    //         } catch (Exception $error) {
    //             Log::record('短信记录异常：', $error->getMessage());
    //         }
    //         return true;
    //     }
    //     return false;
    // }
    // /**
    //  * 发送短信通知代理商，有超时未接的订单
    //  */
    // public static function sendAgentOrderNoticeSms($mobile, $tel, $order_id)
    // {
    //     $config = Config::get("tplmsg.smsConfig");
    //     $smstype = 'ordernotice';
    //     $smstemplate = 'SMS_240395601';
    //     $easySms = new EasySms($config);
    //     $info = '点点达来新的订单了，客户电话:' . $tel . '，请尽快处理';
    //     try {
    //         $result = $easySms->send(
    //             $mobile,
    //             [
    //                 'content'  => '',
    //                 'template' => $smstemplate,
    //                 'data' => [
    //                     'tel' => $tel
    //                 ]
    //             ],
    //             ['aliyun']
    //         );
    //     } catch (Exception $e) {
    //         Log::write("错误", json_encode($e));
    //     }
    //     $res = json_decode(json_encode($result), true);
    //     if ($res['aliyun']['status'] == "success") {
    //         try {
    //             DayuSmsModel::insertData($smstype, '', $mobile, $res['aliyun']['result'], '洗车订单', $info, $order_id);
    //         } catch (Exception $error) {
    //             Log::record('短信记录异常：', $error->getMessage());
    //         }
    //         return true;
    //     }
    //     return false;
    // }
    // /**
    //  * 发送短信通知客服，有超时未接的订单
    //  */
    // public static function sendOrderNoticeSms($mobile, $addr, $order_id, $agentMobile, $siteMobile)
    // {
    //     $config = Config::get("tplmsg.smsConfig");
    //     $smstype = 'ordernotice';
    //     $smstemplate = 'SMS_243216226';
    //     $easySms = new EasySms($config);
    //     $info = $addr . '有未接订单,订单ID：' . $order_id . ',代理商电话：' . $agentMobile . ',站点电话：' . $siteMobile;
    //     try {
    //         $result = $easySms->send(
    //             $mobile,
    //             [
    //                 'content'  => '',
    //                 'template' => $smstemplate,
    //                 'data' => [
    //                     'addr' => $addr,
    //                     'order' => $order_id,
    //                     'agent' => $agentMobile,
    //                     'street' => $siteMobile,
    //                 ]
    //             ],
    //             ['aliyun']
    //         );
    //     } catch (Exception $e) {
    //         Log::write("错误", json_encode($e));
    //     }
    //     $res = json_decode(json_encode($result), true);
    //     if ($res['aliyun']['status'] == "success") {
    //         try {
    //             DayuSmsModel::insertData($smstype, '', $mobile, $res['aliyun']['result'], '洗车订单', $info, $order_id);
    //         } catch (Exception $error) {
    //             Log::record('短信记录异常：', $error->getMessage());
    //         }
    //         return true;
    //     }
    //     return false;
    // }
    // /**
    //  * 发送短信，提醒管理员有未审核的洗车工身份认证申请
    //  */
    // public static function sendWasherApplyNotice($addr, $mobile = '18770001107')
    // {
    //     $config = Config::get("tplmsg.smsConfig");
    //     $smstype = 'ordernotice';
    //     $smstemplate = 'SMS_243160123';
    //     $easySms = new EasySms($config);
    //     $info = '来自地区：' . $addr . '有新的洗车技师申请身份认证了，请及时进行审核';
    //     try {
    //         $result = $easySms->send(
    //             $mobile,
    //             [
    //                 'content'  => '',
    //                 'template' => $smstemplate,
    //                 'data' => [
    //                     'name' => $addr
    //                 ]
    //             ],
    //             ['aliyun']
    //         );
    //     } catch (Exception $e) {
    //         Log::write("错误", json_encode($e));
    //     }
    //     $res = json_decode(json_encode($result), true);
    //     if ($res['aliyun']['status'] == "success") {
    //         try {
    //             DayuSmsModel::insertData($smstype, '', $mobile, $res['aliyun']['result'], '洗车工审核', $info, 0);
    //         } catch (Exception $error) {
    //             Log::record('短信记录异常：', $error->getMessage());
    //         }
    //         return true;
    //     }
    //     return false;
    // }



    // /**
    //  * @description: 洗车工洗车完成通知车主
    //  * @param {*}
    //  * @return {*}
    //  */
    // public static function sendcarowner($mobile)
    // {
    //     $config = Config::get("tplmsg.smsConfig");
    //     $smstype = 'washercarcomplete';
    //     $smstemplate = 'SMS_246805153';
    //     $easySms = new EasySms($config);
    //     $info = "尊敬的车主，您的爱车已经结束洗车服务，请您及时查看结束本次订单。期待下一次为您服务。祝您一路顺风！";
    //     try {
    //         $result = $easySms->send(
    //             $mobile,
    //             [
    //                 'content'  => '',
    //                 'template' => $smstemplate,
    //                 'data' => []
    //             ],
    //             ['aliyun']
    //         );
    //     } catch (Exception $e) {
    //         Log::write("错误", json_encode($e));
    //     }
    //     $res = json_decode(json_encode($result), true);
    //     if ($res['aliyun']['status'] == "success") {
    //         try {
    //             DayuSmsModel::insertData($smstype, '', $mobile, $res['aliyun']['result'], '洗车完成通知车主', $info);
    //         } catch (Exception $error) {
    //             Log::record('短信记录异常：', $error->getMessage());
    //         }
    //         return true;
    //     }
    //     return false;
    // }

    // /**
    //  * @description: 通知洗车工有新的订单已经派给他了
    //  * @param {*}
    //  * @return {*}
    //  */
    // public static function noticeWasherAutoArrangeOrder($mobile, $order_id)
    // {
    //     $config = Config::get("tplmsg.smsConfig");
    //     $smstype = 'autoarrangeorder';
    //     $smstemplate = 'SMS_246825225';
    //     $easySms = new EasySms($config);
    //     $info = "尊敬的洗车技师，有新的洗车订单派给你了，请尽快联系车主，如不接受后续派单，请将状态设为忙碌，如需派给其他人，请联系客服进行处理。";
    //     try {
    //         $result = $easySms->send(
    //             $mobile,
    //             [
    //                 'content'  => '',
    //                 'template' => $smstemplate,
    //                 'data' => []
    //             ],
    //             ['aliyun']
    //         );
    //     } catch (Exception $e) {
    //         Log::write("错误", json_encode($e));
    //     }
    //     $res = json_decode(json_encode($result), true);
    //     if ($res['aliyun']['status'] == "success") {
    //         try {
    //             DayuSmsModel::insertData($smstype, '', $mobile, $res['aliyun']['result'], '自动派单通知洗车工', $info, $order_id);
    //         } catch (Exception $error) {
    //             Log::record('短信记录异常：', $error->getMessage());
    //         }
    //         return true;
    //     }
    //     return false;
    // }

}
